==> koffice2_1.9.93.orig.tar.gz: koffice-1.9.93/karbon/plugins/tools/KarbonToolsPlugin.cpp <==
/* This file is part of the KDE project
 * Copyright (C) 2007 Jan Hambrecht <jaham@gmx.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "KarbonToolsPlugin.h"
#include "KarbonPencilToolFactory.h"
#include "KarbonGradientToolFactory.h"
#include "KarbonPatternToolFactory.h"

#include <KoToolRegistry.h>
#include <kgenericfactory.h>

K_EXPORT_COMPONENT_FACTORY(karbontools, KGenericFactory<KarbonToolsPlugin>( "KarbonTools" ) )

KarbonToolsPlugin::KarbonToolsPlugin( QObject *parent, const QStringList& )
    : QObject(parent)
{
    KoToolRegistry::instance()->add( new KarbonPencilToolFactory( parent ) );
    KoToolRegistry::instance()->add( new KarbonGradientToolFactory( parent ) );
    KoToolRegistry::instance()->add( new KarbonPatternToolFactory( parent ) );
}

#include "KarbonToolsPlugin.moc"

==> koffice2_1.9.95.orig.tar.gz: koffice-1.9.95/karbon/plugins/tools/KarbonToolsPlugin.cpp <==
/* This file is part of the KDE project
 * Copyright (C) 2007 Jan Hambrecht <jaham@gmx.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "KarbonToolsPlugin.h"
#include "KarbonPencilToolFactory.h"
#include "KarbonGradientToolFactory.h"
#include "KarbonPatternToolFactory.h"

#include <KoToolRegistry.h>

#include <KPluginFactory>
#include <KPluginLoader>

K_PLUGIN_FACTORY( KarbonToolsPluginFactory, registerPlugin<KarbonToolsPlugin>(); )
K_EXPORT_PLUGIN( KarbonToolsPluginFactory("KarbonTools") )

KarbonToolsPlugin::KarbonToolsPlugin( QObject *parent, const QVariantList& )
    : QObject(parent)
{
    KoToolRegistry::instance()->add( new KarbonPencilToolFactory( parent ) );
    KoToolRegistry::instance()->add( new KarbonGradientToolFactory( parent ) );
    KoToolRegistry::instance()->add( new KarbonPatternToolFactory( parent ) );
}

#include "KarbonToolsPlugin.moc"
